import type { Database } from 'jsr:@db/sqlite';
import type { NostrEvent, NostrFilter } from 'jsr:@nostrify/types';

export class UserConnection {
  public socket: WebSocket;
  public subscriptions: Map<string, NostrFilter[]>;
  public db: Database;

  constructor(
    socket: WebSocket,
    subscriptions: Map<string, NostrFilter[]>,
    db: Database,
  ) {
    this.socket = socket;
    this.subscriptions = subscriptions;
    this.db = db;
  }

  /**
   * Sends a response to the client
   * @param responseArray The response array to send
   */
  sendResponse(responseArray: unknown[]): void {
    this.socket.send(JSON.stringify(responseArray));
  }

  /**
   * Sends a notice to the client
   * @param message The message to send
   */
  sendNotice(message: string): void {
    this.sendResponse(['NOTICE', message]);
  }

  /**
   * Sends an event to the client
   * @param subscriptionId The subscription ID
   * @param event The event to send
   */
  sendEvent(subscriptionId: string, event: NostrEvent): void {
    this.sendResponse(['EVENT', subscriptionId, event]);
  }

  /**
   * Sends an end of stored events message
   * @param subscriptionId The subscription ID
   */
  sendEOSE(subscriptionId: string): void {
    this.sendResponse(['EOSE', subscriptionId]);
  }

  /**
   * Sends an OK response
   * @param eventId The event ID
   * @param success Whether the operation was successful
   * @param message The message to send
   */
  sendOK(eventId: string, success: boolean, message: string): void {
    this.sendResponse(['OK', eventId, success, message]);
  }
}
