import type { NostrEvent } from 'jsr:@nostrify/types';
import type { UserConnection } from '../UserConnection.ts';

export function filtersMatchingEvent(
  event: NostrEvent,
  connection: UserConnection,
): string[] {
  const matching = [];
  for (const subscription of connection.subscriptions.keys()) {
    const filters = connection.subscriptions.get(subscription);
    if (!filters) continue;
    const isMatching = filters.some((filter) =>
      Object.entries(filter).every(([type, value]) => {
        if (type === 'ids') return value.includes(event.id);
        if (type === 'kinds') return value.includes(event.kind);
        if (type === 'authors') return value.includes(event.pubkey);
        if (type === 'since') return event.created_at > value;
        if (type === 'until') return event.created_at <= value;
        if (type === 'limit') return true;
        if (type.startsWith('#')) {
          const tagName = type.slice(1);
          return event.tags.some(
            (tag: string[]) => tag[0] === tagName && value.includes(tag[1]),
          );
        }
        return false;
      }),
    );
    if (isMatching) matching.push(subscription);
  }
  return matching;
}
