import { decodeBase64 } from 'jsr:@std/encoding@~0.224.1/base64';
import { exists } from 'jsr:@std/fs/exists';
import { decryptUint8Array, encryptionKey } from './encryption.ts';
import { getEveFilePath } from './files.ts';

/**
 * Get the private key for a specific CCN
 */
export async function getCCNPrivateKeyByPubkey(
  pubkey: string,
): Promise<Uint8Array> {
  const ccnPrivPath = await getEveFilePath(`ccn_keys/${pubkey}`);

  if (await exists(ccnPrivPath)) {
    const encryptedPrivateKey = Deno.readTextFileSync(ccnPrivPath);
    return decryptUint8Array(decodeBase64(encryptedPrivateKey), encryptionKey);
  }

  throw new Error(`CCN private key for ${pubkey} not found`);
}
